import{s as e,b as r,a,S as s}from"./chunk-AQP2D5EJ-BKdJwxXK.js";import{_ as i}from"./mermaid.core-G6fbZRPf.js";import"./chunk-55IACEB6-C98HgCsS.js";import"./chunk-2J33WTMH-BPwxCEro.js";import"./index-gE8OWwj_.js";var p={parser:a,get db(){return new s(2)},renderer:r,styles:e,init:i(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{p as diagram};
