// Force strict mode and setup for ESM
"use strict";
import {
  createWorkspaceProvidersStatusProvider
} from "./chunk-OE2QT7SG.js";
import "./chunk-YA423L5V.js";
import "./chunk-IOR5SUL5.js";
import "./chunk-SFLRBXV4.js";
import "./chunk-45LUTRWI.js";
import "./chunk-RKUWKYED.js";
import "./chunk-NIIX6Y2O.js";
import "./chunk-6KNRVSRI.js";
import "./chunk-GOXKNSDZ.js";
import "./chunk-QRUIS3DN.js";
import "./chunk-IDS7MSUP.js";
import "./chunk-Z4ZEXUZG.js";
import "./chunk-ALGGS7UH.js";
import "./chunk-MR3PXB6E.js";
import "./chunk-OWAK7LMW.js";
import "./chunk-2MWHVNSM.js";
import "./chunk-T4TZQJ7W.js";
import "./chunk-H6XPXXMH.js";
import "./chunk-5M6IDOMF.js";
import "./chunk-T2L47JJK.js";
import "./chunk-GPSKDNEE.js";
import "./chunk-X6N25LXS.js";
import "./chunk-E2UVIFI2.js";
import "./chunk-Q2YKNMLS.js";
import "./chunk-XU457J4V.js";
import "./chunk-VDDGDZMA.js";
import "./chunk-KHOVYUHX.js";
import "./chunk-SZRN75WQ.js";
import "./chunk-6PVPNMXU.js";
import "./chunk-VWYINXDB.js";
import "./chunk-CPBF7KYF.js";
import "./chunk-NABLFI57.js";
import "./chunk-QBUDF33N.js";
import "./chunk-LIZRAKPB.js";
import "./chunk-WHGVTP7Q.js";
import "./chunk-6AM5D4ME.js";
import "./chunk-JCW2R7WC.js";
import "./chunk-57FIIFJN.js";
import "./chunk-HTO4JFDZ.js";
import "./chunk-XVNQMZ2I.js";
import "./chunk-FODK6UMO.js";
import "./chunk-GLNBDYUX.js";
import "./chunk-5YMPVE5X.js";
import "./chunk-JESCGQM3.js";
import "./chunk-TULTPXPE.js";
import "./chunk-EHPOFGVJ.js";
import "./chunk-DJ2GSRLV.js";
import "./chunk-5I5BM454.js";
import "./chunk-TMSMMRTT.js";
import "./chunk-VGC4I5JJ.js";
import "./chunk-4K56OJFJ.js";
import "./chunk-JYS55H6Z.js";
import "./chunk-A4UCTEB5.js";
import "./chunk-XWRJCPHC.js";
import "./chunk-QNLNLENL.js";
import "./chunk-6X4GWOPW.js";
import "./chunk-TYQMGACW.js";
import "./chunk-TYAMGABM.js";
import "./chunk-FCMNKVXT.js";
import "./chunk-IS2SBY6T.js";
import "./chunk-HTR4WV6U.js";
import "./chunk-M7WBGLYP.js";
import "./chunk-U7ZFW55U.js";
import "./chunk-NPQDJGKU.js";
import "./chunk-YM3SZTH4.js";
import "./chunk-OQB4EXO4.js";
import "./chunk-75DOP5OR.js";
import "./chunk-DMTGGOSA.js";
import "./chunk-YQ3U5MUC.js";
import "./chunk-THJNPLI4.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export {
  createWorkspaceProvidersStatusProvider
};
