import{s as a,c as s,a as e,C as t}from"./chunk-727SXJPM-cDu-ge-q.js";import{_ as i}from"./mermaid.core-G6fbZRPf.js";import"./chunk-FMBD7UC4-DnuxqwMu.js";import"./chunk-ND2GUHAM-C4fZNPv0.js";import"./chunk-55IACEB6-C98HgCsS.js";import"./chunk-2J33WTMH-BPwxCEro.js";import"./index-gE8OWwj_.js";var n={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{n as diagram};
